Learn R Programming

GSAfisherCombined (version 1.0)

GSAfisher.print: GSAfisher.print

Description

Print method of GSAfisher function that computes the p-value for a joint test of association between a phenotype and a set of genetic variants (SNPs) by combining marginal p-values using the Fisher method and prints the result.

Usage

# S3 method for print
GSAfisher(x,…)

Arguments

x

Numeric set of marginal p-values (one vector or a single p-value).

Further arguments passed to or from other methods.

Value

print.p

Displays Fisher method combined pvalue.

Examples

Run this code
# NOT RUN {
#Generate 1000 random values from an Uniform distribution U(0, 0.25). 
x<-runif(1000, 0, 0.25)
#Set data class to "print".
class(x)<-"print"
#Apply the GSAfisher.print function to this data vector.
GSAfisher(x)
# }

Run the code above in your browser using DataLab