It is a generic function that dispatches different methods. It provides the p-value for a joint test of association between a phenotype and a set of genetic variants (SNPs) by combining marginal p-values using the Fisher method.
Usage
GSAfisher(x,…)
Arguments
x
Set of marginal p-values.
…
Further arguments passed to other methods.
Value
UseMethod("GSAfisher")
Details
Use methods("GSAfisher") to get all the methods for the GSAfisher generic.
References
Fisher, R.A. (1925). Statistical Methods for Research Workers. ISBN 0-05-002170-2.