Default method of GSAfisher function that computes the p-value for a joint test of association between a phenotype and a set of genetic variants (SNPs) by combining marginal p-values using the Fisher method.
Usage
# S3 method for default
GSAfisher(x,…)
Arguments
x
Numeric set of marginal p-values (one vector or a sinlge p-value).
…
Further arguments passed to or from other methods.
Value
p
Fisher method combined p-value.
References
Fisher, R.A. (1925). Statistical Methods for Research Workers. ISBN 0-05-002170-2.
# NOT RUN {#Generate 1000 random values from an Uniform distribution U (0, 0.25). x<-runif(1000, 0, 0.25)
#Apply the GSAfisher.default function to this data vector.GSAfisher(x)
# }